@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '0.44';
+our $VERSION = '0.88';
 
 sub new {
 	my ($class) = @_;
@@ -286,9 +286,11 @@ sub PT::UpperRange::X {
 
 sub PT::IfElse::X {
     my ($class, $className) = @_;
-	my $if = $class->{If}->X($className);
+    my $if = $class->{If}->X($className);
+    
     my $elsif;
     my $else;
+    
     if( exists $class->{ElsIf} ) {
         $elsif = $class->{ElsIf}->X($className);
     }
@@ -313,8 +315,10 @@ sub PT::IfElse::X {
 sub PT::IfElseIf::X {
     my ($class, $className) = @_;
     my $if = $class->{If}->X($className);
+    
     my $elsif;
     my $else;
+    
     if( exists $class->{ElsIf} ) {
         $elsif = $class->{ElsIf}->X($className);
     }
@@ -398,6 +402,7 @@ sub PT::BoolOperands::X {
 sub PT::ElsIf::X {
     my ($class, $className) = @_;
     my @elsIfChain;
+    
     for my $element ( @{$class->{ElsIfChain}} ) {
         push @elsIfChain, $element->X($className);
     }
@@ -527,15 +532,15 @@ sub PT::ListElements::X {
 
 sub PT::ListElement::X {
     my ($class, $className) = @_;
-    return (       $class->{RealNumber}
-                || $class->{String}
-                || $class->{ArrayList}
-                || $class->{HashRef}
-				|| $class->{ClassFunctionReturn}
-				|| $class->{FunctionReturn}
-				|| $class->{ArrayElement}
-				|| $class->{HashElement}
-				|| $class->{VariableName} )->X($className);
+    return (	   $class->{RealNumber}
+		|| $class->{String}
+		|| $class->{ArrayList}
+		|| $class->{HashRef}
+		|| $class->{ClassFunctionReturn}
+		|| $class->{FunctionReturn}
+		|| $class->{ArrayElement}
+		|| $class->{HashElement}
+		|| $class->{VariableName} )->X($className);
 }
 
 sub PT::HashDeclaration::X {
@@ -911,13 +916,13 @@ sub PT::CalcOperator::X {
 
 sub PT::Return::X {
     my ($class, $className) = @_;
-	if(exists $class->{RHS}) {
-		my $rhs = $class->{RHS}->X($className);
-	    my $return = "return " . $rhs . ";\n";
-		return $return;
-	} else {
-		return "return;";
-	}
+    if(exists $class->{RHS}) {
+        my $rhs = $class->{RHS}->X($className);
+        my $return = "return " . $rhs . ";\n";
+	return $return;
+    } else {
+        return "return;";
+    }
 }
 
 sub PT::Last::X {
@@ -1015,10 +1020,7 @@ sub PT::LogicalOr::X {
 }
 
 my $parser = qr {
-    #<nocontext:>
-	<debug: off>
-	#<logfile: parserLog>
-	#<timeout: 100>
+    <nocontext:>
 
     <Lang>
     <objrule:  PT::Lang>                       <[Class]>+
@@ -1063,7 +1065,7 @@ my $parser = qr {
     <objrule:  PT::BoolExpression>             <BoolOperands> <BoolOperatorExpression>?
     <objrule:  PT::BoolOperatorExpression>     <BoolOperator> <BoolOperands>
     <objrule:  PT::BoolOperands>               <RealNumber> | <String> | <ScalarVariable> | <ArrayElement> | <HashElement>
-											   | <ClassFunctionReturn> | <FunctionReturn>
+						| <ClassFunctionReturn> | <FunctionReturn>
     <objrule:  PT::BoolOperator>               <GreaterThan> | <LessThan> | <Equals> | <GreaterThanEquals> | <LessThanEquals>
                                                | <StringEquals> | <StringNotEquals> | <NotEqulas> | <LogicalAnd> | <LogicalOr>
     <objrule:  PT::ElsIf>                      <[ElsIfChain]>+
@@ -1082,7 +1084,7 @@ my $parser = qr {
     <objtoken: PT::VariableName>               [a-zA-Z]+?
     <objrule:  PT::Value>                      <RHS>
     <objtoken: PT::Number>                     [0-9]+
-	<objtoken: PT::RealNumber>                 [-]?\d+\.?\d+|\d+
+    <objtoken: PT::RealNumber>                 [-]?[0-9]+\.?[0-9]+|[0-9]+
     <objrule:  PT::String>                     <LQuote> <StringValue> <RQuote>
     <objrule:  PT::LQuote>                     <Quote>
     <objrule:  PT::RQuote>                     <Quote>
@@ -1092,7 +1094,7 @@ my $parser = qr {
     <objrule:  PT::ArrayList>                  <LBracket> <ListElements> <RBracket>
     <objrule:  PT::ListElements>               .{0} | <[ListElement]>+ % <Comma>
     <objrule:  PT::ListElement>                <RealNumber> | <String> | <ClassFunctionReturn> | <FunctionReturn>
-											   | <ArrayElement> | <HashElement> | <ArrayList> | <HashRef> | <VariableName>
+						| <ArrayElement> | <HashElement> | <ArrayList> | <HashRef> | <VariableName>
 
     <objrule:  PT::HashDeclaration>            <Var> <VariableName> <Equal> <HashRef> <SemiColon>
     <objrule:  PT::HashRef>                    <LBrace> <KeyValuePairs> <RBrace>
@@ -1100,7 +1102,7 @@ my $parser = qr {
     <objrule:  PT::KeyValue>                   <PairKey> <Colon> <PairValue>
     <objrule:  PT::PairKey>                    <Number> | <String>
     <objrule:  PT::PairValue>                  <RealNumber> | <String> | <ClassFunctionReturn> | <FunctionReturn>
-											   | <ArrayElement> | <HashElement> | <ArrayList> | <HashRef> | <VariableName>
+						| <ArrayElement> | <HashElement> | <ArrayList> | <HashRef> | <VariableName>
 
     <objrule:  PT::FunctionCall>               <FunctionName> <LParen> <Parameters>? <RParen> <SemiColon>
     <objrule:  PT::Parameters>                 <[Param]>+ % <Comma>
@@ -1194,7 +1196,7 @@ sub parse {
         return $code;
     } else {
         my $notMatch = "print 'not valid source';";
-		return $notMatch;
+	return $notMatch;
     }
 }
 
